Index: Ringtoets/Piping/src/Ringtoets.Piping.IO/Builders/SoilLayer1D.cs
===================================================================
diff -u -r8ed108b83f575f6cb7dc1b89224606894a4bcb7a -r751aaf9b7623bac357cbacf4e6ddae87b2b69f1f
--- Ringtoets/Piping/src/Ringtoets.Piping.IO/Builders/SoilLayer1D.cs (.../SoilLayer1D.cs) (revision 8ed108b83f575f6cb7dc1b89224606894a4bcb7a)
+++ Ringtoets/Piping/src/Ringtoets.Piping.IO/Builders/SoilLayer1D.cs (.../SoilLayer1D.cs) (revision 751aaf9b7623bac357cbacf4e6ddae87b2b69f1f)
@@ -55,12 +55,6 @@
public double? AbovePhreaticLevel { get; set; }
///
- /// Gets or sets the volumic weight of the below the phreatic level.
- /// [kN/m³]
- ///
- public double? BelowPhreaticLevel { get; set; }
-
- ///
/// Gets or sets the dry unit weight for the .
///
public double? DryUnitWeight { get; set; }
@@ -76,6 +70,85 @@
public double? Color { get; set; }
///
+ /// Gets or sets the distribution for the volumic weight of the below the
+ /// phreatic level.
+ /// [kN/m³]
+ ///
+ public double? BelowPhreaticLevelDistribution { get; set; }
+
+ ///
+ /// Gets or sets the shift of the distribution for the volumic weight of the
+ /// below the phreatic level.
+ /// [kN/m³]
+ ///
+ public double? BelowPhreaticLevelShift { get; set; }
+
+ ///
+ /// Gets or sets the mean of the distribution for the volumic weight of the
+ /// below the phreatic level.
+ /// [kN/m³]
+ ///
+ public double? BelowPhreaticLevelMean { get; set; }
+
+ ///
+ /// Gets or sets the deviation of the distribution for the volumic weight of the below the phreatic level.
+ /// [kN/m³]
+ ///
+ public double? BelowPhreaticLevelDeviation { get; set; }
+
+ ///
+ /// Gets or sets the distribution for the mean diameter of small scale tests applied to different kinds of sand, on which the
+ /// formula of Sellmeijer has been fit.
+ /// [m]
+ ///
+ public double? DiameterD70Distribution { get; set; }
+
+ ///
+ /// Gets or sets the shift of the distribution for the mean diameter of small scale tests applied to different kinds of sand,
+ /// on which the formula of Sellmeijer has been fit.
+ /// [m]
+ ///
+ public double? DiameterD70Shift { get; set; }
+
+ ///
+ /// Gets or sets the mean of the distribution for the mean diameter of small scale tests applied to different kinds of sand,
+ /// on which the formula of Sellmeijer has been fit.
+ /// [m]
+ ///
+ public double? DiameterD70Mean { get; set; }
+
+ ///
+ /// Gets or sets the deviation of the distribution for the mean diameter of small scale tests applied to different kinds of sand,
+ /// on which the formula of Sellmeijer has been fit.
+ /// [m]
+ ///
+ public double? DiameterD70Deviation { get; set; }
+
+ ///
+ /// Gets or sets the distribution for the Darcy-speed with which water flows through the aquifer layer.
+ /// [m/s]
+ ///
+ public double? PermeabilityDistribution { get; set; }
+
+ ///
+ /// Gets or sets the shift of the distribution for the Darcy-speed with which water flows through the aquifer layer.
+ /// [m/s]
+ ///
+ public double? PermeabilityShift { get; set; }
+
+ ///
+ /// Gets or sets the mean of the distribution for the the Darcy-speed with which water flows through the aquifer layer.
+ /// [m/s]
+ ///
+ public double? PermeabilityMean { get; set; }
+
+ ///
+ /// Gets or sets the deviation of the distribution for the Darcy-speed with which water flows through the aquifer layer.
+ /// [m/s]
+ ///
+ public double? PermeabilityDeviation { get; set; }
+
+ ///
/// Constructs a (1D) based on the properties set for the .
///
/// The with properties corresponding to those set on the .
@@ -84,7 +157,7 @@
return new PipingSoilLayer(Top)
{
AbovePhreaticLevel = AbovePhreaticLevel,
- BelowPhreaticLevel = BelowPhreaticLevel,
+ BelowPhreaticLevel = BelowPhreaticLevelMean,
DryUnitWeight = DryUnitWeight,
IsAquifer = IsAquifer.HasValue && IsAquifer.Value.Equals(1.0),
MaterialName = MaterialName ?? string.Empty,
Index: Ringtoets/Piping/src/Ringtoets.Piping.IO/SoilProfile/PipingSoilProfileReader.cs
===================================================================
diff -u -r49f905d3363336d44ef828259692644dcf5f9edc -r751aaf9b7623bac357cbacf4e6ddae87b2b69f1f
--- Ringtoets/Piping/src/Ringtoets.Piping.IO/SoilProfile/PipingSoilProfileReader.cs (.../PipingSoilProfileReader.cs) (revision 49f905d3363336d44ef828259692644dcf5f9edc)
+++ Ringtoets/Piping/src/Ringtoets.Piping.IO/SoilProfile/PipingSoilProfileReader.cs (.../PipingSoilProfileReader.cs) (revision 751aaf9b7623bac357cbacf4e6ddae87b2b69f1f)
@@ -241,38 +241,62 @@
string subQueryGetMaterialPropertiesOfLayer =
String.Format(
"SELECT " +
- "mat.MA_ID, " +
- "mat.MA_Name as {4}, " +
- "MAX(case when pn.PN_NAME = '{0}' then pv.PV_Value end) {0}, " +
- "MAX(case when pn.PN_NAME = '{1}' then pv.PV_Value end) {1}, " +
- "MAX(case when pn.PN_NAME = '{2}' then pv.PV_Value end) {2}, " +
- "MAX(case when pn.PN_NAME = '{3}' then pv.PV_Value end) {3} " +
- "FROM ParameterNames as pn " +
- "JOIN ParameterValues as pv USING(PN_ID) " +
- "JOIN Materials as mat USING(MA_ID) " +
- "GROUP BY mat.MA_ID",
+ "mat.MA_ID, " +
+ "mat.MA_Name as {0}, " +
+ "max(case when pn.PN_Name = 'Color' then pv.PV_Value end) {1}, " +
+ "max(case when pn.PN_Name = 'AbovePhreaticLevel' then pv.PV_Value end) {2}, " +
+ "max(case when pn.PN_Name = 'DryUnitWeight' then pv.PV_Value end) {3}, " +
+ "max(case when pn.PN_Name = 'BelowPhreaticLevelStochast' then s.ST_Dist_Type end) {4}, " +
+ "max(case when pn.PN_Name = 'BelowPhreaticLevelStochast' then s.ST_Shift end) {5}, " +
+ "max(case when pn.PN_Name = 'BelowPhreaticLevelStochast' then s.ST_Mean end) {6}, " +
+ "max(case when pn.PN_Name = 'BelowPhreaticLevelStochast' then s.ST_Deviation end) {7}, " +
+ "max(case when pn.PN_Name = 'PermeabKxStochast' then s.ST_Dist_Type end) {8}, " +
+ "max(case when pn.PN_Name = 'PermeabKxStochast' then s.ST_Shift end) {9}, " +
+ "max(case when pn.PN_Name = 'PermeabKxStochast' then s.ST_Mean end) {10}, " +
+ "max(case when pn.PN_Name = 'PermeabKxStochast' then s.ST_Deviation end) {11}, " +
+ "max(case when pn.PN_Name = 'DiameterD70Stochast' then s.ST_Dist_Type end) {12}, " +
+ "max(case when pn.PN_Name = 'DiameterD70Stochast' then s.ST_Shift end) {13}, " +
+ "max(case when pn.PN_Name = 'DiameterD70Stochast' then s.ST_Mean end) {14}, " +
+ "max(case when pn.PN_Name = 'DiameterD70Stochast' then s.ST_Deviation end) {15} " +
+ "FROM ParameterNames AS pn " +
+ "LEFT JOIN ParameterValues AS pv USING(PN_ID) " +
+ "LEFT JOIN Stochast AS s USING(PN_ID) " +
+ "JOIN Materials AS mat WHERE pv.MA_ID = mat.MA_ID OR s.MA_ID = mat.MA_ID " +
+ "GROUP BY mat.MA_ID ",
+ SoilProfileDatabaseColumns.MaterialName,
+ SoilProfileDatabaseColumns.Color,
SoilProfileDatabaseColumns.AbovePhreaticLevel,
- SoilProfileDatabaseColumns.BelowPhreaticLevel,
SoilProfileDatabaseColumns.DryUnitWeight,
- SoilProfileDatabaseColumns.Color,
- SoilProfileDatabaseColumns.MaterialName);
+ SoilProfileDatabaseColumns.BelowPhreaticLevelDistribution,
+ SoilProfileDatabaseColumns.BelowPhreaticLevelShift,
+ SoilProfileDatabaseColumns.BelowPhreaticLevelMean,
+ SoilProfileDatabaseColumns.BelowPhreaticLevelDeviation,
+ SoilProfileDatabaseColumns.PermeabilityDistribution,
+ SoilProfileDatabaseColumns.PermeabilityShift,
+ SoilProfileDatabaseColumns.PermeabilityMean,
+ SoilProfileDatabaseColumns.PermeabilityDeviation,
+ SoilProfileDatabaseColumns.DiameterD70Distribution,
+ SoilProfileDatabaseColumns.DiameterD70Shift,
+ SoilProfileDatabaseColumns.DiameterD70Mean,
+ SoilProfileDatabaseColumns.DiameterD70Deviation
+ );
string subQueryGetLayerPropertiesOfLayer1D =
String.Format(
"SELECT " +
"SL1D_ID, " +
- "MAX(case when pn.PN_NAME = '{0}' then pv.PV_Value end) {0} " +
- "FROM ParameterNames as pn " +
- "JOIN LayerParameterValues as pv USING(PN_ID) " +
- "GROUP BY pv.SL1D_ID",
+ "PV_Value as {0} " +
+ "FROM ParameterNames " +
+ "JOIN LayerParameterValues USING(PN_ID) " +
+ "WHERE PN_NAME = '{0}'",
SoilProfileDatabaseColumns.IsAquifer);
string subQueryGetLayerPropertiesOfLayer2D =
String.Format(
"SELECT " +
"SL2D_ID, " +
- "MAX(case when pn.PN_NAME = '{0}' then pv.PV_Value end) {0} " +
- "FROM ParameterNames as pn " +
- "JOIN LayerParameterValues as pv USING(PN_ID) " +
- "GROUP BY pv.SL2D_ID",
+ "PV_Value as {0} " +
+ "FROM ParameterNames " +
+ "JOIN LayerParameterValues USING(PN_ID) " +
+ "WHERE PN_NAME = '{0}'",
SoilProfileDatabaseColumns.IsAquifer);
var query1D = string.Format(
@@ -283,12 +307,23 @@
"sp1d.BottomLevel AS {3}, " +
"sl1d.TopLevel AS {4}, " +
"{5}, " +
- "{6}, " +
- "{7}, " +
+ "{6}, " +
+ "{7}, " +
"{8}, " +
"{9}, " +
"{10}, " +
- "sp1d.SP1D_ID AS {11} " +
+ "{11}, " +
+ "{12}, " +
+ "{13}, " +
+ "{14}, " +
+ "{15}, " +
+ "{16}, " +
+ "{17}, " +
+ "{18}, " +
+ "{19}, " +
+ "{20}, " +
+ "{21}, " +
+ "sp1d.SP1D_ID AS {22} " +
"FROM Mechanism AS m " +
"JOIN Segment AS segment USING(ME_ID) " +
"JOIN StochasticSoilProfile ssp USING(SSM_ID) " +
@@ -303,23 +338,34 @@
"LEFT JOIN (" +
subQueryGetLayerPropertiesOfLayer1D +
") layerProperties USING(SL1D_ID) " +
- "WHERE m.{12} = @{12};",
+ "WHERE m.{23} = @{23};",
SoilProfileDatabaseColumns.Dimension,
SoilProfileDatabaseColumns.ProfileName,
SoilProfileDatabaseColumns.LayerCount,
SoilProfileDatabaseColumns.Bottom,
SoilProfileDatabaseColumns.Top,
SoilProfileDatabaseColumns.MaterialName,
- SoilProfileDatabaseColumns.AbovePhreaticLevel,
- SoilProfileDatabaseColumns.BelowPhreaticLevel,
- SoilProfileDatabaseColumns.DryUnitWeight,
SoilProfileDatabaseColumns.IsAquifer,
SoilProfileDatabaseColumns.Color,
+ SoilProfileDatabaseColumns.AbovePhreaticLevel,
+ SoilProfileDatabaseColumns.DryUnitWeight,
+ SoilProfileDatabaseColumns.BelowPhreaticLevelDistribution,
+ SoilProfileDatabaseColumns.BelowPhreaticLevelShift,
+ SoilProfileDatabaseColumns.BelowPhreaticLevelMean,
+ SoilProfileDatabaseColumns.BelowPhreaticLevelDeviation,
+ SoilProfileDatabaseColumns.DiameterD70Distribution,
+ SoilProfileDatabaseColumns.DiameterD70Shift,
+ SoilProfileDatabaseColumns.DiameterD70Mean,
+ SoilProfileDatabaseColumns.DiameterD70Deviation,
+ SoilProfileDatabaseColumns.PermeabilityDistribution,
+ SoilProfileDatabaseColumns.PermeabilityShift,
+ SoilProfileDatabaseColumns.PermeabilityMean,
+ SoilProfileDatabaseColumns.PermeabilityDeviation,
SoilProfileDatabaseColumns.SoilProfileId,
MechanismDatabaseColumns.MechanismName);
var query2D = string.Format(
- "Select " +
+ "SELECT " +
"2 as {0}, " +
"sp2d.SP2D_Name as {1}, " +
"layerCount.{2}, " +
@@ -331,7 +377,18 @@
"{8}, " +
"{9}, " +
"{10}, " +
- "sp2d.SP2D_ID as {11} " +
+ "{11}, " +
+ "{12}, " +
+ "{13}, " +
+ "{14}, " +
+ "{15}, " +
+ "{16}, " +
+ "{17}, " +
+ "{18}, " +
+ "{19}, " +
+ "{20}, " +
+ "{21}, " +
+ "sp2d.SP2D_ID as {22} " +
"FROM Mechanism AS m " +
"JOIN Segment AS segment USING(ME_ID) " +
"JOIN StochasticSoilProfile ssp USING(SSM_ID) " +
@@ -347,18 +404,29 @@
"LEFT JOIN (" +
subQueryGetLayerPropertiesOfLayer2D +
") layerProperties USING(SL2D_ID) " +
- "WHERE m.{12} = @{12};",
+ "WHERE m.{23} = @{23};",
SoilProfileDatabaseColumns.Dimension,
SoilProfileDatabaseColumns.ProfileName,
SoilProfileDatabaseColumns.LayerCount,
SoilProfileDatabaseColumns.LayerGeometry,
SoilProfileDatabaseColumns.IntersectionX,
SoilProfileDatabaseColumns.MaterialName,
- SoilProfileDatabaseColumns.AbovePhreaticLevel,
- SoilProfileDatabaseColumns.BelowPhreaticLevel,
- SoilProfileDatabaseColumns.DryUnitWeight,
SoilProfileDatabaseColumns.IsAquifer,
SoilProfileDatabaseColumns.Color,
+ SoilProfileDatabaseColumns.AbovePhreaticLevel,
+ SoilProfileDatabaseColumns.DryUnitWeight,
+ SoilProfileDatabaseColumns.BelowPhreaticLevelDistribution,
+ SoilProfileDatabaseColumns.BelowPhreaticLevelShift,
+ SoilProfileDatabaseColumns.BelowPhreaticLevelMean,
+ SoilProfileDatabaseColumns.BelowPhreaticLevelDeviation,
+ SoilProfileDatabaseColumns.DiameterD70Distribution,
+ SoilProfileDatabaseColumns.DiameterD70Shift,
+ SoilProfileDatabaseColumns.DiameterD70Mean,
+ SoilProfileDatabaseColumns.DiameterD70Deviation,
+ SoilProfileDatabaseColumns.PermeabilityDistribution,
+ SoilProfileDatabaseColumns.PermeabilityShift,
+ SoilProfileDatabaseColumns.PermeabilityMean,
+ SoilProfileDatabaseColumns.PermeabilityDeviation,
SoilProfileDatabaseColumns.SoilProfileId,
MechanismDatabaseColumns.MechanismName);
Index: Ringtoets/Piping/src/Ringtoets.Piping.IO/SoilProfile/SoilProfile1DReader.cs
===================================================================
diff -u -r49f905d3363336d44ef828259692644dcf5f9edc -r751aaf9b7623bac357cbacf4e6ddae87b2b69f1f
--- Ringtoets/Piping/src/Ringtoets.Piping.IO/SoilProfile/SoilProfile1DReader.cs (.../SoilProfile1DReader.cs) (revision 49f905d3363336d44ef828259692644dcf5f9edc)
+++ Ringtoets/Piping/src/Ringtoets.Piping.IO/SoilProfile/SoilProfile1DReader.cs (.../SoilProfile1DReader.cs) (revision 751aaf9b7623bac357cbacf4e6ddae87b2b69f1f)
@@ -93,11 +93,25 @@
var pipingSoilLayer = new SoilLayer1D(properties.Top)
{
IsAquifer = properties.IsAquifer,
- BelowPhreaticLevel = properties.BelowPhreaticLevel,
AbovePhreaticLevel = properties.AbovePhreaticLevel,
DryUnitWeight = properties.DryUnitWeight,
MaterialName = properties.MaterialName,
- Color = properties.Color
+ Color = properties.Color,
+
+ BelowPhreaticLevelDistribution = properties.BelowPhreaticLevelDistribution,
+ BelowPhreaticLevelShift = properties.BelowPhreaticLevelShift,
+ BelowPhreaticLevelMean = properties.BelowPhreaticLevelMean,
+ BelowPhreaticLevelDeviation = properties.BelowPhreaticLevelDeviation,
+
+ DiameterD70Distribution = properties.DiameterD70Distribution,
+ DiameterD70Shift = properties.DiameterD70Shift,
+ DiameterD70Mean = properties.DiameterD70Mean,
+ DiameterD70Deviation = properties.DiameterD70Deviation,
+
+ PermeabilityDistribution = properties.PermeabilityDistribution,
+ PermeabilityShift = properties.PermeabilityShift,
+ PermeabilityMean = properties.PermeabilityMean,
+ PermeabilityDeviation = properties.PermeabilityDeviation
};
return pipingSoilLayer;
}
@@ -106,12 +120,26 @@
{
internal readonly double Top;
internal readonly double? IsAquifer;
- internal readonly double? BelowPhreaticLevel;
- internal readonly double? AbovePhreaticLevel;
- internal readonly double? DryUnitWeight;
internal readonly string MaterialName;
internal readonly double? Color;
+ internal readonly double? AbovePhreaticLevel;
+ internal readonly double? DryUnitWeight;
+ internal readonly double? BelowPhreaticLevelDistribution;
+ internal readonly double? BelowPhreaticLevelShift;
+ internal readonly double? BelowPhreaticLevelMean;
+ internal readonly double? BelowPhreaticLevelDeviation;
+
+ internal readonly double? DiameterD70Distribution;
+ internal readonly double? DiameterD70Shift;
+ internal readonly double? DiameterD70Mean;
+ internal readonly double? DiameterD70Deviation;
+
+ internal readonly double? PermeabilityDistribution;
+ internal readonly double? PermeabilityShift;
+ internal readonly double? PermeabilityMean;
+ internal readonly double? PermeabilityDeviation;
+
///
/// Creates a new instance of , which contains properties
/// that are required to create a complete . If these properties
@@ -131,20 +159,43 @@
readColumn = SoilProfileDatabaseColumns.IsAquifer;
IsAquifer = reader.ReadOrDefault(readColumn);
- readColumn = SoilProfileDatabaseColumns.BelowPhreaticLevel;
- BelowPhreaticLevel = reader.ReadOrDefault(readColumn);
+ readColumn = SoilProfileDatabaseColumns.MaterialName;
+ MaterialName = reader.ReadOrDefault(readColumn);
+ readColumn = SoilProfileDatabaseColumns.Color;
+ Color = reader.ReadOrDefault(readColumn);
+
readColumn = SoilProfileDatabaseColumns.AbovePhreaticLevel;
AbovePhreaticLevel = reader.ReadOrDefault(readColumn);
-
readColumn = SoilProfileDatabaseColumns.DryUnitWeight;
DryUnitWeight = reader.ReadOrDefault(readColumn);
- readColumn = SoilProfileDatabaseColumns.MaterialName;
- MaterialName = reader.ReadOrDefault(readColumn);
+ readColumn = SoilProfileDatabaseColumns.BelowPhreaticLevelDistribution;
+ BelowPhreaticLevelDistribution = reader.ReadOrDefault(readColumn);
+ readColumn = SoilProfileDatabaseColumns.BelowPhreaticLevelShift;
+ BelowPhreaticLevelShift = reader.ReadOrDefault(readColumn);
+ readColumn = SoilProfileDatabaseColumns.BelowPhreaticLevelMean;
+ BelowPhreaticLevelMean = reader.ReadOrDefault(readColumn);
+ readColumn = SoilProfileDatabaseColumns.BelowPhreaticLevelDeviation;
+ BelowPhreaticLevelDeviation = reader.ReadOrDefault(readColumn);
- readColumn = SoilProfileDatabaseColumns.Color;
- Color = reader.ReadOrDefault(readColumn);
+ readColumn = SoilProfileDatabaseColumns.DiameterD70Distribution;
+ DiameterD70Distribution = reader.ReadOrDefault(readColumn);
+ readColumn = SoilProfileDatabaseColumns.DiameterD70Shift;
+ DiameterD70Shift = reader.ReadOrDefault(readColumn);
+ readColumn = SoilProfileDatabaseColumns.DiameterD70Mean;
+ DiameterD70Mean = reader.ReadOrDefault(readColumn);
+ readColumn = SoilProfileDatabaseColumns.DiameterD70Deviation;
+ DiameterD70Deviation = reader.ReadOrDefault(readColumn);
+
+ readColumn = SoilProfileDatabaseColumns.PermeabilityDistribution;
+ PermeabilityDistribution = reader.ReadOrDefault(readColumn);
+ readColumn = SoilProfileDatabaseColumns.PermeabilityShift;
+ PermeabilityShift = reader.ReadOrDefault(readColumn);
+ readColumn = SoilProfileDatabaseColumns.PermeabilityMean;
+ PermeabilityMean = reader.ReadOrDefault(readColumn);
+ readColumn = SoilProfileDatabaseColumns.PermeabilityDeviation;
+ PermeabilityDeviation = reader.ReadOrDefault(readColumn);
}
catch (InvalidCastException e)
{
Index: Ringtoets/Piping/src/Ringtoets.Piping.IO/SoilProfile/SoilProfile2DReader.cs
===================================================================
diff -u -r49f905d3363336d44ef828259692644dcf5f9edc -r751aaf9b7623bac357cbacf4e6ddae87b2b69f1f
--- Ringtoets/Piping/src/Ringtoets.Piping.IO/SoilProfile/SoilProfile2DReader.cs (.../SoilProfile2DReader.cs) (revision 49f905d3363336d44ef828259692644dcf5f9edc)
+++ Ringtoets/Piping/src/Ringtoets.Piping.IO/SoilProfile/SoilProfile2DReader.cs (.../SoilProfile2DReader.cs) (revision 751aaf9b7623bac357cbacf4e6ddae87b2b69f1f)
@@ -21,7 +21,6 @@
using System;
using System.Data.SQLite;
-using System.Drawing;
using Core.Common.IO.Readers;
using Core.Common.Utils.Builders;
using Ringtoets.Piping.IO.Builders;
@@ -109,11 +108,26 @@
if (pipingSoilLayer != null)
{
pipingSoilLayer.IsAquifer = properties.IsAquifer;
- pipingSoilLayer.BelowPhreaticLevel = properties.BelowPhreaticLevel;
pipingSoilLayer.AbovePhreaticLevel = properties.AbovePhreaticLevel;
pipingSoilLayer.DryUnitWeight = properties.DryUnitWeight;
pipingSoilLayer.MaterialName = properties.MaterialName;
pipingSoilLayer.Color = properties.Color;
+
+ pipingSoilLayer.BelowPhreaticLevelDistribution = properties.BelowPhreaticLevelDistribution;
+ pipingSoilLayer.BelowPhreaticLevelShift = properties.BelowPhreaticLevelShift;
+ pipingSoilLayer.BelowPhreaticLevelMean = properties.BelowPhreaticLevelMean;
+ pipingSoilLayer.BelowPhreaticLevelDeviation = properties.BelowPhreaticLevelDeviation;
+
+ pipingSoilLayer.DiameterD70Distribution = properties.DiameterD70Distribution;
+ pipingSoilLayer.DiameterD70Shift = properties.DiameterD70Shift;
+ pipingSoilLayer.DiameterD70Mean = properties.DiameterD70Mean;
+ pipingSoilLayer.DiameterD70Deviation = properties.DiameterD70Deviation;
+
+ pipingSoilLayer.PermeabilityDistribution = properties.PermeabilityDistribution;
+ pipingSoilLayer.PermeabilityShift = properties.PermeabilityShift;
+ pipingSoilLayer.PermeabilityMean = properties.PermeabilityMean;
+ pipingSoilLayer.PermeabilityDeviation = properties.PermeabilityDeviation;
+
}
return pipingSoilLayer;
}
@@ -155,12 +169,27 @@
private class LayerProperties
{
internal readonly double? IsAquifer;
- internal readonly double? BelowPhreaticLevel;
- internal readonly double? AbovePhreaticLevel;
- internal readonly double? DryUnitWeight;
internal readonly string MaterialName;
internal readonly double? Color;
+ internal readonly double? AbovePhreaticLevel;
+ internal readonly double? DryUnitWeight;
+ internal readonly double? BelowPhreaticLevelDistribution;
+ internal readonly double? BelowPhreaticLevelShift;
+ internal readonly double? BelowPhreaticLevelMean;
+ internal readonly double? BelowPhreaticLevelDeviation;
+
+ internal readonly double? DiameterD70Distribution;
+ internal readonly double? DiameterD70Shift;
+ internal readonly double? DiameterD70Mean;
+ internal readonly double? DiameterD70Deviation;
+
+ internal readonly double? PermeabilityDistribution;
+ internal readonly double? PermeabilityShift;
+ internal readonly double? PermeabilityMean;
+ internal readonly double? PermeabilityDeviation;
+
+
///
/// Creates a new instance of , which contains properties
/// that are required to create a complete . If these properties
@@ -177,20 +206,43 @@
{
IsAquifer = reader.ReadOrDefault(readColumn);
- readColumn = SoilProfileDatabaseColumns.BelowPhreaticLevel;
- BelowPhreaticLevel = reader.ReadOrDefault(readColumn);
+ readColumn = SoilProfileDatabaseColumns.MaterialName;
+ MaterialName = reader.ReadOrDefault(readColumn);
+ readColumn = SoilProfileDatabaseColumns.Color;
+ Color = reader.ReadOrDefault(readColumn);
+
readColumn = SoilProfileDatabaseColumns.AbovePhreaticLevel;
AbovePhreaticLevel = reader.ReadOrDefault(readColumn);
-
readColumn = SoilProfileDatabaseColumns.DryUnitWeight;
DryUnitWeight = reader.ReadOrDefault(readColumn);
- readColumn = SoilProfileDatabaseColumns.MaterialName;
- MaterialName = reader.ReadOrDefault(readColumn);
+ readColumn = SoilProfileDatabaseColumns.BelowPhreaticLevelDistribution;
+ BelowPhreaticLevelDistribution = reader.ReadOrDefault(readColumn);
+ readColumn = SoilProfileDatabaseColumns.BelowPhreaticLevelShift;
+ BelowPhreaticLevelShift = reader.ReadOrDefault(readColumn);
+ readColumn = SoilProfileDatabaseColumns.BelowPhreaticLevelMean;
+ BelowPhreaticLevelMean = reader.ReadOrDefault(readColumn);
+ readColumn = SoilProfileDatabaseColumns.BelowPhreaticLevelDeviation;
+ BelowPhreaticLevelDeviation = reader.ReadOrDefault(readColumn);
- readColumn = SoilProfileDatabaseColumns.Color;
- Color = reader.ReadOrDefault(readColumn);
+ readColumn = SoilProfileDatabaseColumns.DiameterD70Distribution;
+ DiameterD70Distribution = reader.ReadOrDefault(readColumn);
+ readColumn = SoilProfileDatabaseColumns.DiameterD70Shift;
+ DiameterD70Shift = reader.ReadOrDefault(readColumn);
+ readColumn = SoilProfileDatabaseColumns.DiameterD70Mean;
+ DiameterD70Mean = reader.ReadOrDefault(readColumn);
+ readColumn = SoilProfileDatabaseColumns.DiameterD70Deviation;
+ DiameterD70Deviation = reader.ReadOrDefault(readColumn);
+
+ readColumn = SoilProfileDatabaseColumns.PermeabilityDistribution;
+ PermeabilityDistribution = reader.ReadOrDefault(readColumn);
+ readColumn = SoilProfileDatabaseColumns.PermeabilityShift;
+ PermeabilityShift = reader.ReadOrDefault(readColumn);
+ readColumn = SoilProfileDatabaseColumns.PermeabilityMean;
+ PermeabilityMean = reader.ReadOrDefault(readColumn);
+ readColumn = SoilProfileDatabaseColumns.PermeabilityDeviation;
+ PermeabilityDeviation = reader.ReadOrDefault(readColumn);
}
catch (InvalidCastException e)
{
Index: Ringtoets/Piping/src/Ringtoets.Piping.IO/SoilProfile/SoilProfileDatabaseColumns.cs
===================================================================
diff -u -r7e53fcef8411be3bba8f9a7daeae64bbdc491077 -r751aaf9b7623bac357cbacf4e6ddae87b2b69f1f
--- Ringtoets/Piping/src/Ringtoets.Piping.IO/SoilProfile/SoilProfileDatabaseColumns.cs (.../SoilProfileDatabaseColumns.cs) (revision 7e53fcef8411be3bba8f9a7daeae64bbdc491077)
+++ Ringtoets/Piping/src/Ringtoets.Piping.IO/SoilProfile/SoilProfileDatabaseColumns.cs (.../SoilProfileDatabaseColumns.cs) (revision 751aaf9b7623bac357cbacf4e6ddae87b2b69f1f)
@@ -38,8 +38,19 @@
internal const string MaterialName = "MaterialName";
internal const string LayerGeometry = "LayerGeometry";
internal const string AbovePhreaticLevel = "AbovePhreaticLevel";
- internal const string BelowPhreaticLevel = "BelowPhreaticLevel";
internal const string DryUnitWeight = "DryUnitWeight";
+ internal const string BelowPhreaticLevelDistribution = "BelowPhreaticLevelDistribution";
+ internal const string BelowPhreaticLevelShift = "BelowPhreaticLevelShift";
+ internal const string BelowPhreaticLevelMean = "BelowPhreaticLevelMean";
+ internal const string BelowPhreaticLevelDeviation = "BelowPhreaticLevelDeviation";
+ internal const string PermeabilityDistribution = "PermeabKxDistribution";
+ internal const string PermeabilityShift = "PermeabKxShift";
+ internal const string PermeabilityMean = "PermeabKxMean";
+ internal const string PermeabilityDeviation = "PermeabKxDeviation";
+ internal const string DiameterD70Distribution = "DiameterD70Distribution";
+ internal const string DiameterD70Shift = "DiameterD70Shift";
+ internal const string DiameterD70Mean = "DiameterD70Mean";
+ internal const string DiameterD70Deviation = "DiameterD70Deviation";
internal const string LayerCount = "LayerCount";
}
}
\ No newline at end of file
Index: Ringtoets/Piping/test/Ringtoets.Piping.IO.Test/Builders/SoilLayer1DTest.cs
===================================================================
diff -u -r8ed108b83f575f6cb7dc1b89224606894a4bcb7a -r751aaf9b7623bac357cbacf4e6ddae87b2b69f1f
--- Ringtoets/Piping/test/Ringtoets.Piping.IO.Test/Builders/SoilLayer1DTest.cs (.../SoilLayer1DTest.cs) (revision 8ed108b83f575f6cb7dc1b89224606894a4bcb7a)
+++ Ringtoets/Piping/test/Ringtoets.Piping.IO.Test/Builders/SoilLayer1DTest.cs (.../SoilLayer1DTest.cs) (revision 751aaf9b7623bac357cbacf4e6ddae87b2b69f1f)
@@ -1,4 +1,25 @@
-using System;
+// Copyright (C) Stichting Deltares 2016. All rights reserved.
+//
+// This file is part of Ringtoets.
+//
+// Ringtoets is free software: you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with this program. If not, see .
+//
+// All names, logos, and references to "Deltares" are registered trademarks of
+// Stichting Deltares and remain full property of Stichting Deltares at all times.
+// All rights reserved.
+
+using System;
using System.Drawing;
using NUnit.Framework;
using Ringtoets.Piping.IO.Builders;
@@ -21,11 +42,25 @@
// Assert
Assert.AreEqual(top, layer.Top);
Assert.IsNull(layer.AbovePhreaticLevel);
- Assert.IsNull(layer.BelowPhreaticLevel);
Assert.IsNull(layer.DryUnitWeight);
Assert.IsNull(layer.IsAquifer);
Assert.IsNull(layer.MaterialName);
Assert.IsNull(layer.Color);
+
+ Assert.IsNull(layer.BelowPhreaticLevelDistribution);
+ Assert.IsNull(layer.BelowPhreaticLevelShift);
+ Assert.IsNull(layer.BelowPhreaticLevelMean);
+ Assert.IsNull(layer.BelowPhreaticLevelDeviation);
+
+ Assert.IsNull(layer.DiameterD70Distribution);
+ Assert.IsNull(layer.DiameterD70Shift);
+ Assert.IsNull(layer.DiameterD70Mean);
+ Assert.IsNull(layer.DiameterD70Deviation);
+
+ Assert.IsNull(layer.PermeabilityDistribution);
+ Assert.IsNull(layer.PermeabilityShift);
+ Assert.IsNull(layer.PermeabilityMean);
+ Assert.IsNull(layer.PermeabilityDeviation);
}
[Test]
@@ -39,18 +74,46 @@
var top = random.NextDouble();
var materialName = "materialX";
var abovePhreaticLevel = random.NextDouble();
- var belowPhreaticLevel = random.NextDouble();
var dryUnitWeight = random.NextDouble();
var color = Color.BlanchedAlmond;
+ var belowPhreaticLevelDistribution = random.Next();
+ var belowPhreaticLevelShift = random.NextDouble();
+ var belowPhreaticLevelMean = random.NextDouble();
+ var belowPhreaticLevelDeviation = random.NextDouble();
+
+ var diameterD70Distribution = random.Next();
+ var diameterD70Shift = random.NextDouble();
+ var diameterD70Mean = random.NextDouble();
+ var diameterD70Deviation = random.NextDouble();
+
+ var permeabilityDistribution = random.Next();
+ var permeabilityShift = random.NextDouble();
+ var permeabilityMean = random.NextDouble();
+ var permeabilityDeviation = random.NextDouble();
+
var layer = new SoilLayer1D(top)
{
MaterialName = materialName,
IsAquifer = isAquifer,
AbovePhreaticLevel = abovePhreaticLevel,
- BelowPhreaticLevel = belowPhreaticLevel,
DryUnitWeight = dryUnitWeight,
- Color = color.ToArgb()
+ Color = color.ToArgb(),
+
+ BelowPhreaticLevelDistribution = belowPhreaticLevelDistribution,
+ BelowPhreaticLevelShift = belowPhreaticLevelShift,
+ BelowPhreaticLevelMean = belowPhreaticLevelMean,
+ BelowPhreaticLevelDeviation = belowPhreaticLevelDeviation,
+
+ DiameterD70Distribution = diameterD70Distribution,
+ DiameterD70Shift = diameterD70Shift,
+ DiameterD70Mean = diameterD70Mean,
+ DiameterD70Deviation = diameterD70Deviation,
+
+ PermeabilityDistribution = permeabilityDistribution,
+ PermeabilityShift = permeabilityShift,
+ PermeabilityMean = permeabilityMean,
+ PermeabilityDeviation = permeabilityDeviation
};
// Call
@@ -60,7 +123,7 @@
Assert.AreEqual(top, result.Top);
Assert.AreEqual(isAquifer.Equals(1.0), result.IsAquifer);
Assert.AreEqual(abovePhreaticLevel, result.AbovePhreaticLevel);
- Assert.AreEqual(belowPhreaticLevel, result.BelowPhreaticLevel);
+ Assert.AreEqual(belowPhreaticLevelMean, result.BelowPhreaticLevel);
Assert.AreEqual(dryUnitWeight, result.DryUnitWeight);
Assert.AreEqual(materialName, result.MaterialName);
Assert.AreEqual(Color.FromArgb(color.ToArgb()), result.Color);
Index: Ringtoets/Piping/test/Ringtoets.Piping.IO.Test/Builders/SoilLayer2DConversionExceptionTest.cs
===================================================================
diff -u -r8293556a04e3650c9978df7a50f8f8ad0d792ed8 -r751aaf9b7623bac357cbacf4e6ddae87b2b69f1f
--- Ringtoets/Piping/test/Ringtoets.Piping.IO.Test/Builders/SoilLayer2DConversionExceptionTest.cs (.../SoilLayer2DConversionExceptionTest.cs) (revision 8293556a04e3650c9978df7a50f8f8ad0d792ed8)
+++ Ringtoets/Piping/test/Ringtoets.Piping.IO.Test/Builders/SoilLayer2DConversionExceptionTest.cs (.../SoilLayer2DConversionExceptionTest.cs) (revision 751aaf9b7623bac357cbacf4e6ddae87b2b69f1f)
@@ -1,4 +1,25 @@
-using System;
+// Copyright (C) Stichting Deltares 2016. All rights reserved.
+//
+// This file is part of Ringtoets.
+//
+// Ringtoets is free software: you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with this program. If not, see .
+//
+// All names, logos, and references to "Deltares" are registered trademarks of
+// Stichting Deltares and remain full property of Stichting Deltares at all times.
+// All rights reserved.
+
+using System;
using NUnit.Framework;
using Ringtoets.Piping.IO.Builders;
Index: Ringtoets/Piping/test/Ringtoets.Piping.IO.Test/Builders/SoilLayer2DTest.cs
===================================================================
diff -u -r8293556a04e3650c9978df7a50f8f8ad0d792ed8 -r751aaf9b7623bac357cbacf4e6ddae87b2b69f1f
--- Ringtoets/Piping/test/Ringtoets.Piping.IO.Test/Builders/SoilLayer2DTest.cs (.../SoilLayer2DTest.cs) (revision 8293556a04e3650c9978df7a50f8f8ad0d792ed8)
+++ Ringtoets/Piping/test/Ringtoets.Piping.IO.Test/Builders/SoilLayer2DTest.cs (.../SoilLayer2DTest.cs) (revision 751aaf9b7623bac357cbacf4e6ddae87b2b69f1f)
@@ -1,4 +1,25 @@
-using System;
+// Copyright (C) Stichting Deltares 2016. All rights reserved.
+//
+// This file is part of Ringtoets.
+//
+// Ringtoets is free software: you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with this program. If not, see .
+//
+// All names, logos, and references to "Deltares" are registered trademarks of
+// Stichting Deltares and remain full property of Stichting Deltares at all times.
+// All rights reserved.
+
+using System;
using System.Collections.Generic;
using System.Drawing;
using System.Linq;
@@ -26,11 +47,25 @@
Assert.IsNull(result.OuterLoop);
CollectionAssert.IsEmpty(result.InnerLoops);
Assert.IsNull(result.AbovePhreaticLevel);
- Assert.IsNull(result.BelowPhreaticLevel);
Assert.IsNull(result.DryUnitWeight);
Assert.IsNull(result.IsAquifer);
Assert.IsNull(result.MaterialName);
Assert.IsNull(result.Color);
+
+ Assert.IsNull(result.BelowPhreaticLevelDistribution);
+ Assert.IsNull(result.BelowPhreaticLevelShift);
+ Assert.IsNull(result.BelowPhreaticLevelMean);
+ Assert.IsNull(result.BelowPhreaticLevelDeviation);
+
+ Assert.IsNull(result.DiameterD70Distribution);
+ Assert.IsNull(result.DiameterD70Shift);
+ Assert.IsNull(result.DiameterD70Mean);
+ Assert.IsNull(result.DiameterD70Deviation);
+
+ Assert.IsNull(result.PermeabilityDistribution);
+ Assert.IsNull(result.PermeabilityShift);
+ Assert.IsNull(result.PermeabilityMean);
+ Assert.IsNull(result.PermeabilityDeviation);
}
[Test]
@@ -245,20 +280,49 @@
var x2 = 1.1;
var x3 = 1.2;
var abovePhreaticLevel = random.NextDouble();
- var belowPhreaticLevel = random.NextDouble();
var dryUnitWeight = random.NextDouble();
var materialName = "materialX";
var color = Color.DarkSeaGreen;
double bottom;
+ var belowPhreaticLevelDistribution = random.Next();
+ var belowPhreaticLevelShift = random.NextDouble();
+ var belowPhreaticLevelMean = random.NextDouble();
+ var belowPhreaticLevelDeviation = random.NextDouble();
+
+ var diameterD70Distribution = random.Next();
+ var diameterD70Shift = random.NextDouble();
+ var diameterD70Mean = random.NextDouble();
+ var diameterD70Deviation = random.NextDouble();
+
+ var permeabilityDistribution = random.Next();
+ var permeabilityShift = random.NextDouble();
+ var permeabilityMean = random.NextDouble();
+ var permeabilityDeviation = random.NextDouble();
+
var layer = new SoilLayer2D
{
MaterialName = materialName,
IsAquifer = 1.0,
AbovePhreaticLevel = abovePhreaticLevel,
- BelowPhreaticLevel = belowPhreaticLevel,
DryUnitWeight = dryUnitWeight,
Color = color.ToArgb(),
+
+ BelowPhreaticLevelDistribution = belowPhreaticLevelDistribution,
+ BelowPhreaticLevelShift = belowPhreaticLevelShift,
+ BelowPhreaticLevelMean = belowPhreaticLevelMean,
+ BelowPhreaticLevelDeviation = belowPhreaticLevelDeviation,
+
+ DiameterD70Distribution = diameterD70Distribution,
+ DiameterD70Shift = diameterD70Shift,
+ DiameterD70Mean = diameterD70Mean,
+ DiameterD70Deviation = diameterD70Deviation,
+
+ PermeabilityDistribution = permeabilityDistribution,
+ PermeabilityShift = permeabilityShift,
+ PermeabilityMean = permeabilityMean,
+ PermeabilityDeviation = permeabilityDeviation,
+
OuterLoop = new List
{
new Segment2D(
@@ -290,7 +354,7 @@
Assert.AreEqual(y2, resultLayer.Top, 1e-6);
Assert.IsTrue(resultLayer.IsAquifer);
Assert.AreEqual(abovePhreaticLevel, resultLayer.AbovePhreaticLevel);
- Assert.AreEqual(belowPhreaticLevel, resultLayer.BelowPhreaticLevel);
+ Assert.AreEqual(belowPhreaticLevelMean, resultLayer.BelowPhreaticLevel);
Assert.AreEqual(dryUnitWeight, resultLayer.DryUnitWeight);
Assert.AreEqual(materialName, resultLayer.MaterialName);
Assert.AreEqual(Color.FromArgb(color.ToArgb()), resultLayer.Color);
Index: Ringtoets/Piping/test/Ringtoets.Piping.IO.Test/Builders/SoilProfileBuilder1DTest.cs
===================================================================
diff -u -r8293556a04e3650c9978df7a50f8f8ad0d792ed8 -r751aaf9b7623bac357cbacf4e6ddae87b2b69f1f
--- Ringtoets/Piping/test/Ringtoets.Piping.IO.Test/Builders/SoilProfileBuilder1DTest.cs (.../SoilProfileBuilder1DTest.cs) (revision 8293556a04e3650c9978df7a50f8f8ad0d792ed8)
+++ Ringtoets/Piping/test/Ringtoets.Piping.IO.Test/Builders/SoilProfileBuilder1DTest.cs (.../SoilProfileBuilder1DTest.cs) (revision 751aaf9b7623bac357cbacf4e6ddae87b2b69f1f)
@@ -1,4 +1,25 @@
-using System;
+// Copyright (C) Stichting Deltares 2016. All rights reserved.
+//
+// This file is part of Ringtoets.
+//
+// Ringtoets is free software: you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with this program. If not, see .
+//
+// All names, logos, and references to "Deltares" are registered trademarks of
+// Stichting Deltares and remain full property of Stichting Deltares at all times.
+// All rights reserved.
+
+using System;
using System.Linq;
using NUnit.Framework;
using Ringtoets.Piping.IO.Builders;
Index: Ringtoets/Piping/test/Ringtoets.Piping.IO.Test/Builders/SoilProfileBuilder2DTest.cs
===================================================================
diff -u -r8293556a04e3650c9978df7a50f8f8ad0d792ed8 -r751aaf9b7623bac357cbacf4e6ddae87b2b69f1f
--- Ringtoets/Piping/test/Ringtoets.Piping.IO.Test/Builders/SoilProfileBuilder2DTest.cs (.../SoilProfileBuilder2DTest.cs) (revision 8293556a04e3650c9978df7a50f8f8ad0d792ed8)
+++ Ringtoets/Piping/test/Ringtoets.Piping.IO.Test/Builders/SoilProfileBuilder2DTest.cs (.../SoilProfileBuilder2DTest.cs) (revision 751aaf9b7623bac357cbacf4e6ddae87b2b69f1f)
@@ -1,4 +1,25 @@
-using System;
+// Copyright (C) Stichting Deltares 2016. All rights reserved.
+//
+// This file is part of Ringtoets.
+//
+// Ringtoets is free software: you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with this program. If not, see .
+//
+// All names, logos, and references to "Deltares" are registered trademarks of
+// Stichting Deltares and remain full property of Stichting Deltares at all times.
+// All rights reserved.
+
+using System;
using System.Collections.Generic;
using System.Linq;
using Core.Common.Base.Geometry;
Index: Ringtoets/Piping/test/Ringtoets.Piping.IO.Test/Builders/SoilProfileBuilderExceptionTest.cs
===================================================================
diff -u -rf69d756f50ae1464a1a11f0780b6d6aa646f3114 -r751aaf9b7623bac357cbacf4e6ddae87b2b69f1f
--- Ringtoets/Piping/test/Ringtoets.Piping.IO.Test/Builders/SoilProfileBuilderExceptionTest.cs (.../SoilProfileBuilderExceptionTest.cs) (revision f69d756f50ae1464a1a11f0780b6d6aa646f3114)
+++ Ringtoets/Piping/test/Ringtoets.Piping.IO.Test/Builders/SoilProfileBuilderExceptionTest.cs (.../SoilProfileBuilderExceptionTest.cs) (revision 751aaf9b7623bac357cbacf4e6ddae87b2b69f1f)
@@ -1,4 +1,25 @@
-using System;
+// Copyright (C) Stichting Deltares 2016. All rights reserved.
+//
+// This file is part of Ringtoets.
+//
+// Ringtoets is free software: you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with this program. If not, see .
+//
+// All names, logos, and references to "Deltares" are registered trademarks of
+// Stichting Deltares and remain full property of Stichting Deltares at all times.
+// All rights reserved.
+
+using System;
using NUnit.Framework;
using Ringtoets.Piping.IO.Builders;
Index: Ringtoets/Piping/test/Ringtoets.Piping.IO.Test/Exceptions/PipingSoilProfileReadExceptionTest.cs
===================================================================
diff -u -r8293556a04e3650c9978df7a50f8f8ad0d792ed8 -r751aaf9b7623bac357cbacf4e6ddae87b2b69f1f
--- Ringtoets/Piping/test/Ringtoets.Piping.IO.Test/Exceptions/PipingSoilProfileReadExceptionTest.cs (.../PipingSoilProfileReadExceptionTest.cs) (revision 8293556a04e3650c9978df7a50f8f8ad0d792ed8)
+++ Ringtoets/Piping/test/Ringtoets.Piping.IO.Test/Exceptions/PipingSoilProfileReadExceptionTest.cs (.../PipingSoilProfileReadExceptionTest.cs) (revision 751aaf9b7623bac357cbacf4e6ddae87b2b69f1f)
@@ -1,4 +1,25 @@
-using System;
+// Copyright (C) Stichting Deltares 2016. All rights reserved.
+//
+// This file is part of Ringtoets.
+//
+// Ringtoets is free software: you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with this program. If not, see .
+//
+// All names, logos, and references to "Deltares" are registered trademarks of
+// Stichting Deltares and remain full property of Stichting Deltares at all times.
+// All rights reserved.
+
+using System;
using NUnit.Framework;
using Ringtoets.Piping.IO.Exceptions;
Index: Ringtoets/Piping/test/Ringtoets.Piping.IO.Test/Properties/AssemblyInfo.cs
===================================================================
diff -u -rdd1a980616ea0f7eaf5593353dc8012a09f4c8c1 -r751aaf9b7623bac357cbacf4e6ddae87b2b69f1f
--- Ringtoets/Piping/test/Ringtoets.Piping.IO.Test/Properties/AssemblyInfo.cs (.../AssemblyInfo.cs) (revision dd1a980616ea0f7eaf5593353dc8012a09f4c8c1)
+++ Ringtoets/Piping/test/Ringtoets.Piping.IO.Test/Properties/AssemblyInfo.cs (.../AssemblyInfo.cs) (revision 751aaf9b7623bac357cbacf4e6ddae87b2b69f1f)
@@ -1,4 +1,25 @@
-using System.Reflection;
+// Copyright (C) Stichting Deltares 2016. All rights reserved.
+//
+// This file is part of Ringtoets.
+//
+// Ringtoets is free software: you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with this program. If not, see .
+//
+// All names, logos, and references to "Deltares" are registered trademarks of
+// Stichting Deltares and remain full property of Stichting Deltares at all times.
+// All rights reserved.
+
+using System.Reflection;
using System.Runtime.InteropServices;
[assembly: AssemblyTitle("Ringtoets.Piping.IO.Test")]
Index: Ringtoets/Piping/test/Ringtoets.Piping.IO.Test/SoilProfile/CriticalProfilePropertiesTest.cs
===================================================================
diff -u -rd2a52a4a27bba0bcf0437e905fe3985484c0219c -r751aaf9b7623bac357cbacf4e6ddae87b2b69f1f
--- Ringtoets/Piping/test/Ringtoets.Piping.IO.Test/SoilProfile/CriticalProfilePropertiesTest.cs (.../CriticalProfilePropertiesTest.cs) (revision d2a52a4a27bba0bcf0437e905fe3985484c0219c)
+++ Ringtoets/Piping/test/Ringtoets.Piping.IO.Test/SoilProfile/CriticalProfilePropertiesTest.cs (.../CriticalProfilePropertiesTest.cs) (revision 751aaf9b7623bac357cbacf4e6ddae87b2b69f1f)
@@ -1,4 +1,25 @@
-using System;
+// Copyright (C) Stichting Deltares 2016. All rights reserved.
+//
+// This file is part of Ringtoets.
+//
+// Ringtoets is free software: you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with this program. If not, see .
+//
+// All names, logos, and references to "Deltares" are registered trademarks of
+// Stichting Deltares and remain full property of Stichting Deltares at all times.
+// All rights reserved.
+
+using System;
using Core.Common.IO.Exceptions;
using Core.Common.IO.Readers;
using Core.Common.Utils.Builders;
Index: Ringtoets/Piping/test/Ringtoets.Piping.IO.Test/SoilProfile/PipingSoilProfileReaderTest.cs
===================================================================
diff -u -r7fae71414e3c8eb1a72de4c173850498104205bd -r751aaf9b7623bac357cbacf4e6ddae87b2b69f1f
--- Ringtoets/Piping/test/Ringtoets.Piping.IO.Test/SoilProfile/PipingSoilProfileReaderTest.cs (.../PipingSoilProfileReaderTest.cs) (revision 7fae71414e3c8eb1a72de4c173850498104205bd)
+++ Ringtoets/Piping/test/Ringtoets.Piping.IO.Test/SoilProfile/PipingSoilProfileReaderTest.cs (.../PipingSoilProfileReaderTest.cs) (revision 751aaf9b7623bac357cbacf4e6ddae87b2b69f1f)
@@ -23,7 +23,6 @@
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Drawing;
-using System.Globalization;
using System.IO;
using System.Linq;
using Core.Common.IO.Exceptions;
@@ -353,12 +352,32 @@
var exceptionMessage = Assert.Throws(profile).Message;
var message = new FileReaderErrorMessageBuilder(databaseFilePath)
.WithSubject("ondergrondschematisatie 'Profile'")
- .Build(string.Format(Resources.PipingSoilProfileReader_Profile_has_invalid_value_on_Column_0_, "DryUnitWeight"));
+ .Build(string.Format(Resources.PipingSoilProfileReader_Profile_has_invalid_value_on_Column_0_, "Color"));
Assert.AreEqual(message, exceptionMessage);
}
}
[Test]
+ public void ReadProfile_DatabaseProfileWithLayerWithInvalidStochastProperty_ReturnsNoProfile()
+ {
+ // Setup
+ var testFile = "incorrectValue2dStochastProperty.soil";
+ string databaseFilePath = Path.Combine(testDataPath, testFile);
+ using (var pipingSoilProfilesReader = new PipingSoilProfileReader(databaseFilePath))
+ {
+ // Call
+ TestDelegate profile = () => pipingSoilProfilesReader.ReadProfile();
+
+ // Assert
+ var exceptionMessage = Assert.Throws(profile).Message;
+ var message = new FileReaderErrorMessageBuilder(databaseFilePath)
+ .WithSubject("ondergrondschematisatie 'Profile'")
+ .Build(string.Format(Resources.PipingSoilProfileReader_Profile_has_invalid_value_on_Column_0_, "BelowPhreaticLevelMean"));
+ Assert.AreEqual(message, exceptionMessage);
+ }
+ }
+
+ [Test]
public void ReadProfile_DatabaseWith1DProfile3Layers_ReturnsProfile()
{
// Setup
@@ -382,24 +401,24 @@
0.001,
0.001
}, profile.Layers.Select(l => l.AbovePhreaticLevel));
- CollectionAssert.AreEqual(new[]
- {
- 0.001,
- 0.001,
- 0.001
- }, profile.Layers.Select(l => l.BelowPhreaticLevel));
CollectionAssert.AreEqual(new double?[]
{
- null,
- null,
- null
+ 0.805,
+ 0.015,
+ 0.005
}, profile.Layers.Select(l => l.DryUnitWeight));
- CollectionAssert.AreEqual(new []
+ CollectionAssert.AreEqual(new[]
{
Color.FromArgb(128,255,128),
Color.FromArgb(255,0,0),
Color.FromArgb(70,130,180)
}, profile.Layers.Select(l => l.Color));
+ CollectionAssert.AreEqual(new[]
+ {
+ 3.88,
+ 0.71,
+ 0.21
+ }, profile.Layers.Select(l => l.BelowPhreaticLevel));
}
}
@@ -427,24 +446,24 @@
0.001,
0.001
}, profile.Layers.Select(l => l.AbovePhreaticLevel));
- CollectionAssert.AreEqual(new[]
- {
- 0.001,
- 0.001,
- 0.001
- }, profile.Layers.Select(l => l.BelowPhreaticLevel));
CollectionAssert.AreEqual(new double?[]
{
- null,
- null,
- null
+ 0.005,
+ 0.015,
+ 0.805
}, profile.Layers.Select(l => l.DryUnitWeight));
CollectionAssert.AreEqual(new []
{
Color.FromArgb(70,130,180),
Color.FromArgb(255,0,0),
Color.FromArgb(128,255,128)
}, profile.Layers.Select(l => l.Color));
+ CollectionAssert.AreEqual(new[]
+ {
+ 0.21,
+ 0.71,
+ 3.88
+ }, profile.Layers.Select(l => l.BelowPhreaticLevel));
}
}
Index: Ringtoets/Piping/test/Ringtoets.Piping.IO.Test/SoilProfile/SoilLayer2DReaderTest.cs
===================================================================
diff -u -r8293556a04e3650c9978df7a50f8f8ad0d792ed8 -r751aaf9b7623bac357cbacf4e6ddae87b2b69f1f
--- Ringtoets/Piping/test/Ringtoets.Piping.IO.Test/SoilProfile/SoilLayer2DReaderTest.cs (.../SoilLayer2DReaderTest.cs) (revision 8293556a04e3650c9978df7a50f8f8ad0d792ed8)
+++ Ringtoets/Piping/test/Ringtoets.Piping.IO.Test/SoilProfile/SoilLayer2DReaderTest.cs (.../SoilLayer2DReaderTest.cs) (revision 751aaf9b7623bac357cbacf4e6ddae87b2b69f1f)
@@ -1,4 +1,25 @@
-using System;
+// Copyright (C) Stichting Deltares 2016. All rights reserved.
+//
+// This file is part of Ringtoets.
+//
+// Ringtoets is free software: you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with this program. If not, see .
+//
+// All names, logos, and references to "Deltares" are registered trademarks of
+// Stichting Deltares and remain full property of Stichting Deltares at all times.
+// All rights reserved.
+
+using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Globalization;
Index: Ringtoets/Piping/test/Ringtoets.Piping.IO.Test/SoilProfile/SoilProfile1DReaderTest.cs
===================================================================
diff -u -r8ed108b83f575f6cb7dc1b89224606894a4bcb7a -r751aaf9b7623bac357cbacf4e6ddae87b2b69f1f
--- Ringtoets/Piping/test/Ringtoets.Piping.IO.Test/SoilProfile/SoilProfile1DReaderTest.cs (.../SoilProfile1DReaderTest.cs) (revision 8ed108b83f575f6cb7dc1b89224606894a4bcb7a)
+++ Ringtoets/Piping/test/Ringtoets.Piping.IO.Test/SoilProfile/SoilProfile1DReaderTest.cs (.../SoilProfile1DReaderTest.cs) (revision 751aaf9b7623bac357cbacf4e6ddae87b2b69f1f)
@@ -1,4 +1,25 @@
-using System;
+// Copyright (C) Stichting Deltares 2016. All rights reserved.
+//
+// This file is part of Ringtoets.
+//
+// Ringtoets is free software: you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with this program. If not, see .
+//
+// All names, logos, and references to "Deltares" are registered trademarks of
+// Stichting Deltares and remain full property of Stichting Deltares at all times.
+// All rights reserved.
+
+using System;
using System.Drawing;
using System.Linq;
using Core.Common.IO.Exceptions;
@@ -204,9 +225,11 @@
reader.Expect(r => r.Read(SoilProfileDatabaseColumns.Bottom)).Return(bottom).Repeat.Any();
reader.Expect(r => r.Read(SoilProfileDatabaseColumns.Top)).Return(top).Repeat.Any();
reader.Expect(r => r.ReadOrDefault(SoilProfileDatabaseColumns.IsAquifer)).Return(isAquifer).Repeat.Any();
- reader.Expect(r => r.ReadOrDefault(SoilProfileDatabaseColumns.BelowPhreaticLevel)).Return(belowPhreaticLevel).Repeat.Any();
reader.Expect(r => r.ReadOrDefault(SoilProfileDatabaseColumns.AbovePhreaticLevel)).Return(abovePhreaticLevel).Repeat.Any();
reader.Expect(r => r.ReadOrDefault(SoilProfileDatabaseColumns.DryUnitWeight)).Return(dryUnitWeight).Repeat.Any();
+ reader.Expect(r => r.ReadOrDefault(SoilProfileDatabaseColumns.BelowPhreaticLevelMean)).Return(belowPhreaticLevel).Repeat.Any();
+ reader.Expect(r => r.ReadOrDefault(SoilProfileDatabaseColumns.DiameterD70Mean)).Return(abovePhreaticLevel).Repeat.Any();
+ reader.Expect(r => r.ReadOrDefault(SoilProfileDatabaseColumns.PermeabilityMean)).Return(dryUnitWeight).Repeat.Any();
reader.Expect(r => r.ReadOrDefault(SoilProfileDatabaseColumns.MaterialName)).Return(materialName).Repeat.Any();
reader.Expect(r => r.ReadOrDefault(SoilProfileDatabaseColumns.Color)).Return(color).Repeat.Any();
}
Index: Ringtoets/Piping/test/Ringtoets.Piping.IO.Test/SoilProfile/SoilProfile2DReaderTest.cs
===================================================================
diff -u -r8ed108b83f575f6cb7dc1b89224606894a4bcb7a -r751aaf9b7623bac357cbacf4e6ddae87b2b69f1f
--- Ringtoets/Piping/test/Ringtoets.Piping.IO.Test/SoilProfile/SoilProfile2DReaderTest.cs (.../SoilProfile2DReaderTest.cs) (revision 8ed108b83f575f6cb7dc1b89224606894a4bcb7a)
+++ Ringtoets/Piping/test/Ringtoets.Piping.IO.Test/SoilProfile/SoilProfile2DReaderTest.cs (.../SoilProfile2DReaderTest.cs) (revision 751aaf9b7623bac357cbacf4e6ddae87b2b69f1f)
@@ -1,4 +1,25 @@
-using System;
+// Copyright (C) Stichting Deltares 2016. All rights reserved.
+//
+// This file is part of Ringtoets.
+//
+// Ringtoets is free software: you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with this program. If not, see .
+//
+// All names, logos, and references to "Deltares" are registered trademarks of
+// Stichting Deltares and remain full property of Stichting Deltares at all times.
+// All rights reserved.
+
+using System;
using System.Drawing;
using System.Linq;
using Core.Common.IO.Exceptions;
@@ -274,9 +295,11 @@
reader.Expect(r => r.Read(SoilProfileDatabaseColumns.ProfileName)).Return(profileName).Repeat.Any();
reader.Expect(r => r.Read(SoilProfileDatabaseColumns.IntersectionX)).Return(intersectionX).Repeat.Any();
reader.Expect(r => r.ReadOrDefault(SoilProfileDatabaseColumns.IsAquifer)).Return(isAquifer).Repeat.Any();
- reader.Expect(r => r.ReadOrDefault(SoilProfileDatabaseColumns.BelowPhreaticLevel)).Return(belowPhreaticLevel).Repeat.Any();
reader.Expect(r => r.ReadOrDefault(SoilProfileDatabaseColumns.AbovePhreaticLevel)).Return(abovePhreaticLevel).Repeat.Any();
reader.Expect(r => r.ReadOrDefault(SoilProfileDatabaseColumns.DryUnitWeight)).Return(dryUnitWeight).Repeat.Any();
+ reader.Expect(r => r.ReadOrDefault(SoilProfileDatabaseColumns.BelowPhreaticLevelMean)).Return(belowPhreaticLevel).Repeat.Any();
+ reader.Expect(r => r.ReadOrDefault(SoilProfileDatabaseColumns.DiameterD70Mean)).Return(abovePhreaticLevel).Repeat.Any();
+ reader.Expect(r => r.ReadOrDefault(SoilProfileDatabaseColumns.PermeabilityMean)).Return(dryUnitWeight).Repeat.Any();
reader.Expect(r => r.ReadOrDefault(SoilProfileDatabaseColumns.MaterialName)).Return(materialName).Repeat.Any();
reader.Expect(r => r.ReadOrDefault(SoilProfileDatabaseColumns.Color)).Return(color).Repeat.Any();
reader.Expect(r => r.Read(SoilProfileDatabaseColumns.LayerGeometry)).Return(geometry).Repeat.Any();
Index: Ringtoets/Piping/test/Ringtoets.Piping.IO.Test/SoilProfile/StochasticSoilProfileReaderTest.cs
===================================================================
diff -u -r973ed43129e04e3bf314d654b5a9ff877f08f175 -r751aaf9b7623bac357cbacf4e6ddae87b2b69f1f
--- Ringtoets/Piping/test/Ringtoets.Piping.IO.Test/SoilProfile/StochasticSoilProfileReaderTest.cs (.../StochasticSoilProfileReaderTest.cs) (revision 973ed43129e04e3bf314d654b5a9ff877f08f175)
+++ Ringtoets/Piping/test/Ringtoets.Piping.IO.Test/SoilProfile/StochasticSoilProfileReaderTest.cs (.../StochasticSoilProfileReaderTest.cs) (revision 751aaf9b7623bac357cbacf4e6ddae87b2b69f1f)
@@ -1,4 +1,25 @@
-using System;
+// Copyright (C) Stichting Deltares 2016. All rights reserved.
+//
+// This file is part of Ringtoets.
+//
+// Ringtoets is free software: you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with this program. If not, see .
+//
+// All names, logos, and references to "Deltares" are registered trademarks of
+// Stichting Deltares and remain full property of Stichting Deltares at all times.
+// All rights reserved.
+
+using System;
using System.IO;
using Core.Common.IO.Exceptions;
using Core.Common.IO.Readers;
Index: Ringtoets/Piping/test/Ringtoets.Piping.IO.Test/SurfaceLines/CharacteristicPointsCsvReaderTest.cs
===================================================================
diff -u -r16d6d5ad38a45e4e0e8b3a9b41b3383d31595a36 -r751aaf9b7623bac357cbacf4e6ddae87b2b69f1f
--- Ringtoets/Piping/test/Ringtoets.Piping.IO.Test/SurfaceLines/CharacteristicPointsCsvReaderTest.cs (.../CharacteristicPointsCsvReaderTest.cs) (revision 16d6d5ad38a45e4e0e8b3a9b41b3383d31595a36)
+++ Ringtoets/Piping/test/Ringtoets.Piping.IO.Test/SurfaceLines/CharacteristicPointsCsvReaderTest.cs (.../CharacteristicPointsCsvReaderTest.cs) (revision 751aaf9b7623bac357cbacf4e6ddae87b2b69f1f)
@@ -1,4 +1,25 @@
-using System;
+// Copyright (C) Stichting Deltares 2016. All rights reserved.
+//
+// This file is part of Ringtoets.
+//
+// Ringtoets is free software: you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with this program. If not, see .
+//
+// All names, logos, and references to "Deltares" are registered trademarks of
+// Stichting Deltares and remain full property of Stichting Deltares at all times.
+// All rights reserved.
+
+using System;
using System.IO;
using Core.Common.Base.Geometry;
using Core.Common.IO.Exceptions;
Index: Ringtoets/Piping/test/Ringtoets.Piping.IO.Test/SurfaceLines/CharacteristicPointsTest.cs
===================================================================
diff -u -r68597fa1a4f4d31ee209873eec139f9412026bd2 -r751aaf9b7623bac357cbacf4e6ddae87b2b69f1f
--- Ringtoets/Piping/test/Ringtoets.Piping.IO.Test/SurfaceLines/CharacteristicPointsTest.cs (.../CharacteristicPointsTest.cs) (revision 68597fa1a4f4d31ee209873eec139f9412026bd2)
+++ Ringtoets/Piping/test/Ringtoets.Piping.IO.Test/SurfaceLines/CharacteristicPointsTest.cs (.../CharacteristicPointsTest.cs) (revision 751aaf9b7623bac357cbacf4e6ddae87b2b69f1f)
@@ -1,4 +1,25 @@
-using System;
+// Copyright (C) Stichting Deltares 2016. All rights reserved.
+//
+// This file is part of Ringtoets.
+//
+// Ringtoets is free software: you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with this program. If not, see .
+//
+// All names, logos, and references to "Deltares" are registered trademarks of
+// Stichting Deltares and remain full property of Stichting Deltares at all times.
+// All rights reserved.
+
+using System;
using NUnit.Framework;
using Ringtoets.Piping.IO.SurfaceLines;
Index: Ringtoets/Piping/test/Ringtoets.Piping.IO.Test/SurfaceLines/PipingSurfaceLinesCsvReaderTest.cs
===================================================================
diff -u -r16d6d5ad38a45e4e0e8b3a9b41b3383d31595a36 -r751aaf9b7623bac357cbacf4e6ddae87b2b69f1f
--- Ringtoets/Piping/test/Ringtoets.Piping.IO.Test/SurfaceLines/PipingSurfaceLinesCsvReaderTest.cs (.../PipingSurfaceLinesCsvReaderTest.cs) (revision 16d6d5ad38a45e4e0e8b3a9b41b3383d31595a36)
+++ Ringtoets/Piping/test/Ringtoets.Piping.IO.Test/SurfaceLines/PipingSurfaceLinesCsvReaderTest.cs (.../PipingSurfaceLinesCsvReaderTest.cs) (revision 751aaf9b7623bac357cbacf4e6ddae87b2b69f1f)
@@ -1,4 +1,25 @@
-using System;
+// Copyright (C) Stichting Deltares 2016. All rights reserved.
+//
+// This file is part of Ringtoets.
+//
+// Ringtoets is free software: you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with this program. If not, see .
+//
+// All names, logos, and references to "Deltares" are registered trademarks of
+// Stichting Deltares and remain full property of Stichting Deltares at all times.
+// All rights reserved.
+
+using System;
using System.IO;
using System.Linq;
using Core.Common.IO.Exceptions;
Index: Ringtoets/Piping/test/Ringtoets.Piping.IO.Test/TestHelpers/StringGeometryHelper.cs
===================================================================
diff -u -r34158466ff227d581f6ba7007092045c9af84508 -r751aaf9b7623bac357cbacf4e6ddae87b2b69f1f
--- Ringtoets/Piping/test/Ringtoets.Piping.IO.Test/TestHelpers/StringGeometryHelper.cs (.../StringGeometryHelper.cs) (revision 34158466ff227d581f6ba7007092045c9af84508)
+++ Ringtoets/Piping/test/Ringtoets.Piping.IO.Test/TestHelpers/StringGeometryHelper.cs (.../StringGeometryHelper.cs) (revision 751aaf9b7623bac357cbacf4e6ddae87b2b69f1f)
@@ -1,4 +1,25 @@
-using System;
+// Copyright (C) Stichting Deltares 2016. All rights reserved.
+//
+// This file is part of Ringtoets.
+//
+// Ringtoets is free software: you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with this program. If not, see .
+//
+// All names, logos, and references to "Deltares" are registered trademarks of
+// Stichting Deltares and remain full property of Stichting Deltares at all times.
+// All rights reserved.
+
+using System;
using System.IO;
using System.Xml;
using System.Xml.Linq;
Index: Ringtoets/Piping/test/Ringtoets.Piping.IO.Test/packages.config
===================================================================
diff -u -r443423bba9710843153b9afda01bbee47cd1b298 -r751aaf9b7623bac357cbacf4e6ddae87b2b69f1f
--- Ringtoets/Piping/test/Ringtoets.Piping.IO.Test/packages.config (.../packages.config) (revision 443423bba9710843153b9afda01bbee47cd1b298)
+++ Ringtoets/Piping/test/Ringtoets.Piping.IO.Test/packages.config (.../packages.config) (revision 751aaf9b7623bac357cbacf4e6ddae87b2b69f1f)
@@ -1,4 +1,27 @@
+
+
Index: Ringtoets/Piping/test/Ringtoets.Piping.IO.Test/test-data/PipingSoilProfilesReader/1dprofile.soil
===================================================================
diff -u -r49f905d3363336d44ef828259692644dcf5f9edc -r751aaf9b7623bac357cbacf4e6ddae87b2b69f1f
Binary files differ
Index: Ringtoets/Piping/test/Ringtoets.Piping.IO.Test/test-data/PipingSoilProfilesReader/2dprofile.soil
===================================================================
diff -u -r49f905d3363336d44ef828259692644dcf5f9edc -r751aaf9b7623bac357cbacf4e6ddae87b2b69f1f
Binary files differ
Index: Ringtoets/Piping/test/Ringtoets.Piping.IO.Test/test-data/PipingSoilProfilesReader/SingleSoilProfile2D_withLayerProperties.soil
===================================================================
diff -u -rcbbe282de6b1e1fb53fa5026dcf7a212ad871455 -r751aaf9b7623bac357cbacf4e6ddae87b2b69f1f
Binary files differ
Index: Ringtoets/Piping/test/Ringtoets.Piping.IO.Test/test-data/PipingSoilProfilesReader/incorrectValue2dProperty.soil
===================================================================
diff -u -rbf334f50530164badedba45a78f3aab857ae1bf6 -r751aaf9b7623bac357cbacf4e6ddae87b2b69f1f
Binary files differ
Index: Ringtoets/Piping/test/Ringtoets.Piping.IO.Test/test-data/PipingSoilProfilesReader/incorrectValue2dStochastProperty.soil
===================================================================
diff -u
Binary files differ
Index: Ringtoets/Piping/test/Ringtoets.Piping.Integration.Test/ImportSoilProfileFromDatabaseTest.cs
===================================================================
diff -u -r8293556a04e3650c9978df7a50f8f8ad0d792ed8 -r751aaf9b7623bac357cbacf4e6ddae87b2b69f1f
--- Ringtoets/Piping/test/Ringtoets.Piping.Integration.Test/ImportSoilProfileFromDatabaseTest.cs (.../ImportSoilProfileFromDatabaseTest.cs) (revision 8293556a04e3650c9978df7a50f8f8ad0d792ed8)
+++ Ringtoets/Piping/test/Ringtoets.Piping.Integration.Test/ImportSoilProfileFromDatabaseTest.cs (.../ImportSoilProfileFromDatabaseTest.cs) (revision 751aaf9b7623bac357cbacf4e6ddae87b2b69f1f)
@@ -78,11 +78,16 @@
}, pipingProfile.Layers.Select(l => l.AbovePhreaticLevel));
CollectionAssert.AreEqual(new[]
{
- 0.001,
- 0.001,
- 0.001
+ 3.88,
+ 0.71,
+ 0.21
}, pipingProfile.Layers.Select(l => l.BelowPhreaticLevel));
- CollectionAssert.AreEqual(Enumerable.Repeat(defaultPipingLayer.DryUnitWeight, 3), pipingProfile.Layers.Select(l => l.DryUnitWeight));
+ CollectionAssert.AreEqual(new double?[]
+ {
+ 0.805,
+ 0.015,
+ 0.005
+ }, profile.Layers.Select(l => l.DryUnitWeight));
CollectionAssert.AreEqual(new[]
{
false,
@@ -140,8 +145,8 @@
CollectionAssert.AreEqual(new[]
{
0.0,
- 0.001,
- 0.009
+ 0.0,
+ 0.0
}, pipingProfile.Layers.Select(l => l.BelowPhreaticLevel));
CollectionAssert.AreEqual(new[]
{
Index: Ringtoets/Piping/src/Ringtoets.Piping.IO/Builders/SoilLayer2D.cs
===================================================================
diff -u -r8ed108b83f575f6cb7dc1b89224606894a4bcb7a -r751aaf9b7623bac357cbacf4e6ddae87b2b69f1f
--- Ringtoets/Piping/src/Ringtoets.Piping.IO/Builders/SoilLayer2D.cs (.../SoilLayer2D.cs) (revision 8ed108b83f575f6cb7dc1b89224606894a4bcb7a)
+++ Ringtoets/Piping/src/Ringtoets.Piping.IO/Builders/SoilLayer2D.cs (.../SoilLayer2D.cs) (revision 751aaf9b7623bac357cbacf4e6ddae87b2b69f1f)
@@ -22,7 +22,6 @@
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
-using System.Drawing;
using System.Linq;
using Core.Common.Base.Geometry;
@@ -61,11 +60,85 @@
public double? AbovePhreaticLevel { get; set; }
///
/// Gets or sets the below phreatic level for the .
///
- public double? BelowPhreaticLevel { get; set; }
+ public double? BelowPhreaticLevelDistribution { get; set; }
///
+ /// Gets or sets the shift of the distribution for the volumic weight of the
+ /// below the phreatic level.
+ /// [kN/m³]
+ ///
+ public double? BelowPhreaticLevelShift { get; set; }
+
+ ///
+ /// Gets or sets the mean of the distribution for the volumic weight of the
+ /// below the phreatic level.
+ /// [kN/m³]
+ ///
+ public double? BelowPhreaticLevelMean { get; set; }
+
+ ///
+ /// Gets or sets the deviation of the distribution for the volumic weight of the below the phreatic level.
+ /// [kN/m³]
+ ///
+ public double? BelowPhreaticLevelDeviation { get; set; }
+
+ ///
+ /// Gets or sets the distribution for the mean diameter of small scale tests applied to different kinds of sand, on which the
+ /// formula of Sellmeijer has been fit.
+ /// [m]
+ ///
+ public double? DiameterD70Distribution { get; set; }
+
+ ///
+ /// Gets or sets the shift of the distribution for the mean diameter of small scale tests applied to different kinds of sand,
+ /// on which the formula of Sellmeijer has been fit.
+ /// [m]
+ ///
+ public double? DiameterD70Shift { get; set; }
+
+ ///
+ /// Gets or sets the mean of the distribution for the mean diameter of small scale tests applied to different kinds of sand,
+ /// on which the formula of Sellmeijer has been fit.
+ /// [m]
+ ///
+ public double? DiameterD70Mean { get; set; }
+
+ ///
+ /// Gets or sets the deviation of the distribution for the mean diameter of small scale tests applied to different kinds of sand,
+ /// on which the formula of Sellmeijer has been fit.
+ /// [m]
+ ///
+ public double? DiameterD70Deviation { get; set; }
+
+ ///
+ /// Gets or sets the distribution for the Darcy-speed with which water flows through the aquifer layer.
+ /// [m/s]
+ ///
+ public double? PermeabilityDistribution { get; set; }
+
+ ///
+ /// Gets or sets the shift of the distribution for the Darcy-speed with which water flows through the aquifer layer.
+ /// [m/s]
+ ///
+ public double? PermeabilityShift { get; set; }
+
+ ///
+ /// Gets or sets the mean of the distribution for the the Darcy-speed with which water flows through the aquifer layer.
+ /// [m/s]
+ ///
+ public double? PermeabilityMean { get; set; }
+
+ ///
+ /// Gets or sets the deviation of the distribution for the Darcy-speed with which water flows through the aquifer layer.
+ /// [m/s]
+ ///
+ public double? PermeabilityDeviation { get; set; }
+
+ ///
/// Gets or sets the dry unit weight for the .
///
public double? DryUnitWeight { get; set; }
@@ -76,7 +149,7 @@
public string MaterialName { get; set; }
///
- /// Gets or sets the value representing a color that was used to represent the .
+ /// Gets or sets the value representing a color that was used to represent the .
///
public double? Color { get; set; }
@@ -157,7 +230,7 @@
result.Add(new PipingSoilLayer(height)
{
IsAquifer = IsAquifer.HasValue && IsAquifer.Value.Equals(1.0),
- BelowPhreaticLevel = BelowPhreaticLevel,
+ BelowPhreaticLevel = BelowPhreaticLevelMean,
AbovePhreaticLevel = AbovePhreaticLevel,
DryUnitWeight = DryUnitWeight,
MaterialName = MaterialName ?? string.Empty,
@@ -61,11 +60,85 @@
public double? AbovePhreaticLevel { get; set; }
///
- /// Gets or sets the below phreatic level for the .
+ /// Gets or sets the distribution for the volumic weight of the below the
+ /// phreatic level.
+ /// [kN/m³]
///